##
##  snmpdx.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2018 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         snmpdx
Summary:      SNMP Daemon Extension
URL:          http://www.ossp.org/pkg/tool/snmpdx/
Vendor:       The OSSP Project
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Networking
License:      GPL
Version:      1.0.0
Release:      20181229

#   list of sources
Source0:      http://www.ossp.org/pkg/tool/snmpdx/snmpdx-%{version}.tar.gz
Source1:      rc.snmpdx

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, perl, snmp
PreReq:       OpenPKG, openpkg >= 20160101, perl, snmp

%description
    OSSP snmpdx is a framework for easily hooking into net-snmp's
    snmpd(8) and providing an own SNMP MIB and the OID implementing
    probes. It is a Perl program which either can be configured as a
    pass (not recommended) or pass_persist (recommended) program into
    snmpd.conf.

%track
    prog snmpdx = {
        version   = %{version}
        url       = http://www.ossp.org/pkg/tool/snmpdx/
        regex     = snmpdx-(__VER__)\.tar\.gz
    }

%prep
    %setup -q

%build
    #   configure program
    ./configure \
        --prefix=%{l_prefix} \
        --with-openpkg=%{l_prefix} \
        --with-snmp=%{l_prefix} \
        --with-perl=%{l_prefix}/bin/perl

    #   build program
    %{l_make} %{l_mflags -O}

%install
    #   install program
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.snmpdx} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/snmpdx/snmpdx.cfg'

%files -f files

%clean

%post
    #   add snmpd(8) hook
    snmpdx_mibprefix=`$RPM_INSTALL_PREFIX/bin/snmptranslate \
        -M $RPM_INSTALL_PREFIX/share/snmp/mibs:$RPM_INSTALL_PREFIX/share/snmpdx -m snmpdx -Ib -On snmpdx`
    echo "pass_persist $snmpdx_mibprefix $RPM_INSTALL_PREFIX/sbin/snmpdx" |\
    $RPM_INSTALL_PREFIX/lib/openpkg/rpmtool config \
        -a -s -i "$RPM_INSTALL_PREFIX:snmpdx" $RPM_INSTALL_PREFIX/etc/snmp/snmpd.conf

%preun
    #   remove snmpd(8) hook
    $RPM_INSTALL_PREFIX/lib/openpkg/rpmtool config \
        -r -s -i "$RPM_INSTALL_PREFIX:snmpdx" $RPM_INSTALL_PREFIX/etc/snmp/snmpd.conf

